##
##  influxdb-relay.spec -- OpenPKG RPM Package Specification
##  Copyright (c) 2000-2020 OpenPKG Project <http://openpkg.org/>
##
##  Permission to use, copy, modify, and distribute this software for
##  any purpose with or without fee is hereby granted, provided that
##  the above copyright notice and this permission notice appear in all
##  copies.
##
##  THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
##  WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
##  MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
##  IN NO EVENT SHALL THE AUTHORS AND COPYRIGHT HOLDERS AND THEIR
##  CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
##  SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
##  LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
##  USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
##  ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
##  OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
##  OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
##  SUCH DAMAGE.
##

#   package information
%define       V_influxdb_relay_base  20200711
%define       V_influxdb_relay_snap  20200711

#   package information
Name:         influxdb-relay
Summary:      Time-Series Database Relay Server
URL:          http://influxdb.com/
Vendor:       Paul Dix & Errplane Inc.
Packager:     OpenPKG Project
Distribution: OpenPKG Community
Class:        EVAL
Group:        Database
License:      MIT
Version:      %{V_influxdb_relay_base}
Release:      20200711

#   list of sources
Source0:      http://download.openpkg.org/components/versioned/influxdb/influxdb-relay-%{V_influxdb_relay_snap}.tar.xz
Source1:      rc.influxdb-relay
Source2:      influxdb-relay.conf

#   build information
BuildPreReq:  OpenPKG, openpkg >= 20160101, go
PreReq:       OpenPKG, openpkg >= 20160101

%description
    InfluxDB is a Time-Series, Metrics and Real-Time Analytics Database.
    This is the corresponding relay server for high-availability setups.

%track
    prog influxdb-relay:release = {
        version   = %{V_influxdb_relay_base}
        url       = https://github.com/influxdata/influxdb-relay/releases
        regex     = v(\d+\.\d+\.\d+)
    }
    prog influxdb-relay:snapshot = {
        version   = %{V_influxdb_relay_snap}
        url       = http://download.openpkg.org/components/versioned/influxdb/
        regex     = influxdb-relay-(__VER__)\.tar\.gz
    }

%prep
    %setup -q -n influxdb-relay

%build
    #   build program
    (   export GOPATH=`pwd`
        cd $GOPATH/src/github.com/influxdata/influxdb-relay
        go build -v -o influxdb-relay main.go
    ) || exit $?

%install
    #   create directory hierarchy
    %{l_shtool} mkdir -f -p -m 755 \
        $RPM_BUILD_ROOT%{l_prefix}/sbin \
        $RPM_BUILD_ROOT%{l_prefix}/etc/rc.d \
        $RPM_BUILD_ROOT%{l_prefix}/etc/influxdb-relay \
        $RPM_BUILD_ROOT%{l_prefix}/var/influxdb-relay/run \
        $RPM_BUILD_ROOT%{l_prefix}/var/influxdb-relay/log

    #   install program
    %{l_shtool} install -c -s -m 755 \
        src/github.com/influxdata/influxdb-relay/influxdb-relay \
        $RPM_BUILD_ROOT%{l_prefix}/sbin/

    #   install run-command script
    %{l_shtool} install -c -m 755 %{l_value -s -a} \
        %{SOURCE rc.influxdb-relay} $RPM_BUILD_ROOT%{l_prefix}/etc/rc.d/

    #   install default configuration
    %{l_shtool} install -c -m 644 %{l_value -s -a} \
        %{SOURCE influxdb-relay.conf} \
        $RPM_BUILD_ROOT%{l_prefix}/etc/influxdb-relay/

    #   determine installation files
    %{l_rpmtool} files -v -ofiles -r$RPM_BUILD_ROOT \
        %{l_files_std} \
        '%config %{l_prefix}/etc/influxdb-relay/*' \
        '%attr(-,%{l_rusr},%{l_rgrp}) %{l_prefix}/var/influxdb-relay/*'

%files -f files

%clean

%post
    if [ $1 -eq 2 ]; then
        #   after upgrade, restart service
        eval `%{l_rc} influxdb-relay status 2>/dev/null`
        [ ".$influxdb_relay_active" = .yes ] && %{l_rc} influxdb-relay restart
    fi
    exit 0

%preun
    if [ $1 -eq 0 ]; then
        #   before erase, stop service and remove log files
        %{l_rc} influxdb-relay stop 2>/dev/null
        rm -rf $RPM_INSTALL_PREFIX/var/influxdb-relay/log/* >/dev/null 2>&1 || true
        rm -rf $RPM_INSTALL_PREFIX/var/influxdb-relay/run/* >/dev/null 2>&1 || true
    fi
    exit 0

